@@ -1,5 +1,5 @@
 """Top-level package for libshipkore."""
 
 __author__ = """Innerkore"""
-__email__ = 'admin@innerkore.com'
-__version__ = '0.1.0'
+__email__ = "admin@innerkore.com"
+__version__ = "0.4.2"
