@@ -6,7 +6,7 @@ import pytest
 
 from click.testing import CliRunner
 
-from libshipkore import libshipkore
+# from libshipkore import libshipkore
 from libshipkore import cli
 
 
@@ -31,7 +31,8 @@ def test_command_line_interface():
     runner = CliRunner()
     result = runner.invoke(cli.main)
     assert result.exit_code == 0
-    assert 'libshipkore.cli.main' in result.output
+    assert 'providers' in result.output
+    assert 'track' in result.output
     help_result = runner.invoke(cli.main, ['--help'])
     assert help_result.exit_code == 0
     assert '--help  Show this message and exit.' in help_result.output
